@@ -25,7 +25,7 @@ import warnings
 import weakref
 import zmq
 
-from kitchen.text.converters import to_utf8
+from kitchen.text.converters import to_bytes
 
 import fedmsg.encoding
 import fedmsg.crypto
@@ -76,8 +76,20 @@ class FedMsgContext(object):
 
             self.c['certname'] = self.c['certnames'][cert_index]
 
+        # Do a little special-case mangling.  We never want to "listen" to the
+        # relay_inbound address, but in the special case that we want to emit
+        # our messages there, we add it to the :term:`endpoints` dict so that
+        # the code below where we "Actually set up our publisher" can be
+        # simplified.  See Issue #37 - http://bit.ly/KN6dEK
+        if config.get('active', False):
+            # If the user has called us with "active=True" then presumably they
+            # have given us a "name" as well.
+            name = config.get("name", "relay_inbound")
+            config['endpoints'][name] = config[name]
+
         # Actually set up our publisher
         if (
+            not config.get("mute", False) and
             config.get("name", None) and
             config.get("endpoints", None) and
             config['endpoints'].get(config['name'])
@@ -118,7 +130,11 @@ class FedMsgContext(object):
             if not _established:
                 raise IOError("Couldn't find an available endpoint.")
 
+        elif config.get('mute', False):
+            # Our caller doesn't intend to send any messages.  Pass silently.
+            pass
         else:
+            # Something is wrong.
             warnings.warn("fedmsg is not configured to send any messages")
 
         # Cleanup.  See http://bit.ly/SaGeOr for discussion.
@@ -129,6 +145,8 @@ class FedMsgContext(object):
         time.sleep(config['post_init_sleep'])
 
     def destroy(self):
+        """ Destroy a fedmsg context """
+
         if getattr(self, 'publisher', None):
             self.publisher.close()
             self.publisher = None
@@ -137,9 +155,6 @@ class FedMsgContext(object):
             self.context.term()
             self.context = None
 
-    def subscribe(self, topic, callback):
-        raise NotImplementedError
-
     # TODO -- this should be in kitchen, not fedmsg
     def guess_calling_module(self, default=None):
         # Iterate up the call-stack and return the first new top-level module
@@ -158,6 +173,70 @@ class FedMsgContext(object):
         return self.publish(topic, msg, modname)
 
     def publish(self, topic=None, msg=None, modname=None):
+        """ Send a message over the publishing zeromq socket.
+
+          >>> import fedmsg
+          >>> fedmsg.publish(topic='testing', modname='test', msg={
+          ...     'test': "Hello World",
+          ... })
+
+        The above snippet will send the message ``'{test: "Hello World"}'``
+        over the ``org.fedoraproject.dev.test.testing`` topic.
+
+        This function (and other API functions) do a little bit more
+        heavy lifting than they let on.  If the "zeromq context" is not yet
+        initialized, :func:`fedmsg.init` is called to construct it and
+        store it as :data:`fedmsg.__local.__context` before anything else is
+        done.
+
+        The ``modname`` argument will be omitted in most use cases.  By
+        default, ``fedmsg`` will try to guess the name of the module that
+        called it and use that to produce an intelligent topic.  Specifying
+        ``modname`` explicitly overrides this behavior.
+
+        The fully qualified topic of a message is constructed out of the
+        following pieces:
+
+         <:term:`topic_prefix`>.<:term:`environment`>.<``modname``>.<``topic``>
+
+        ----
+
+        **An example from Fedora Tagger -- SQLAlchemy encoding**
+
+        Here's an example from
+        `fedora-tagger <http://github.com/ralphbean/fedora-tagger>`_ that
+        sends the information about a new tag over
+        ``org.fedoraproject.{dev,stg,prod}.fedoratagger.tag.update``::
+
+          >>> import fedmsg
+          >>> fedmsg.publish(topic='tag.update', msg={
+          ...     'user': user,
+          ...     'tag': tag,
+          ... })
+
+        Note that the `tag` and `user` objects are SQLAlchemy objects defined
+        by tagger.  They both have ``.__json__()`` methods which
+        :func:`fedmsg.publish` uses to encode both objects as stringified
+        JSON for you.  Under the hood, specifically, ``.publish`` uses
+        :mod:`fedmsg.encoding` to do this.
+
+        ``fedmsg`` has also guessed the module name (``modname``) of it's
+        caller and inserted it into the topic for you.  The code from which
+        we stole the above snippet lives in
+        ``fedoratagger.controllers.root``.  ``fedmsg`` figured that out and
+        stripped it down to just ``fedoratagger`` for the final topic of
+        ``org.fedoraproject.{dev,stg,prod}.fedoratagger.tag.update``.
+
+        ----
+
+        **Shell Usage**
+
+        You could also use the ``fedmsg-logger`` from a shell script like so::
+
+            $ echo "Hello, world." | fedmsg-logger --topic testing
+            $ echo '{"foo": "bar"}' | fedmsg-logger --json-input
+
+        """
 
         if not topic:
             warnings.warn("Attempted to send message with no topic.  Bailing.")
@@ -179,7 +258,7 @@ class FedMsgContext(object):
             ])
 
         if type(topic) == unicode:
-            topic = to_utf8(topic)
+            topic = to_bytes(topic, encoding='utf8', nonstring="passthru")
 
         self._i += 1
         msg = dict(topic=topic, msg=msg, timestamp=time.time(), i=self._i)
@@ -189,11 +268,11 @@ class FedMsgContext(object):
 
         self.publisher.send_multipart([topic, fedmsg.encoding.dumps(msg)])
 
-    def _tail_messages(self, endpoints, topic="", passive=False, **kw):
-        """
-        Generator that yields messages on the bus in the form of tuples::
+    def tail_messages(self, endpoints, topic="", passive=False, **kw):
+        """ Tail messages on the bus.
 
-        >>> (endpoint, topic, message)
+        Generator that yields tuples of the form:
+        ``(name, endpoint, topic, message)``
         """
 
         # TODO -- the 'passive' here and the 'active' are ambiguous.  They
