@@ -19,6 +19,7 @@
 #
 from fedmsg.text.base import BaseProcessor
 
+
 class WikiProcessor(BaseProcessor):
     def handle_subtitle(self, msg, **config):
         return any([
@@ -32,9 +33,8 @@ class WikiProcessor(BaseProcessor):
         if 'wiki.article.edit' in msg['topic']:
             user = msg['msg']['user']
             title = msg['msg']['title']
-            url = msg['msg']['url']
-            tmpl = self._('{user} made a wiki edit to "{title}".  {url}')
-            return tmpl.format(user=user, title=title, url=url)
+            tmpl = self._('{user} made a wiki edit to "{title}".')
+            return tmpl.format(user=user, title=title)
         elif 'wiki.upload.complete' in msg['topic']:
             user = msg['msg']['user_text']
             filename = msg['msg']['title']['mPrefixedText']
@@ -46,3 +46,16 @@ class WikiProcessor(BaseProcessor):
                                description=description)
         else:
             raise NotImplementedError
+
+    def handle_link(self, msg, **config):
+        return any([
+            target in msg['topic'] for target in [
+                'wiki.article.edit',
+            ]
+        ])
+
+    def link(self, msg, **config):
+        if 'wiki.article.edit' in msg['topic']:
+            return msg['msg']['url']
+        else:
+            raise NotImplementedError
