@@ -19,6 +19,7 @@
 #
 from fedmsg.text.base import BaseProcessor
 
+
 class SCMProcessor(BaseProcessor):
     def handle_subtitle(self, msg, **config):
         return '.git.receive.' in msg['topic']
@@ -34,3 +35,18 @@ class SCMProcessor(BaseProcessor):
                                branch=branch, summary=summ)
         else:
             raise NotImplementedError
+
+    def handle_link(self, msg, **config):
+        return '.git.receive.' in msg['topic']
+
+    def link(self, msg, **config):
+        if '.git.receive.' in msg['topic']:
+            repo = '.'.join(msg['topic'].split('.')[5:-1])
+            rev = msg['msg']['commit']['rev']
+            branch = msg['msg']['commit']['branch']
+            prefix = "http://pkgs.fedoraproject.org/cgit"
+            tmpl = "{prefix}/{repo}.git/commit/?h={branch}&id={rev}"
+            return tmpl.format(prefix=prefix, repo=repo,
+                               branch=branch, rev=rev)
+        else:
+            raise NotImplementedError
